@@ -12,14 +12,6 @@
 #'         coefficient of variation to be compared to each other in ways
 #'         that other measures, like standard deviations or root mean
 #'         squared residuals, cannot be.
-#'         \cr \cr
-#'         \dQuote{It is interesting to note the differences between a model's CV
-#'         and R-squared values. Both are unitless measures that are indicative
-#'         of model fit, but they define model fit in two different ways: CV
-#'         evaluates the relative closeness of the predictions to the actual
-#'         values while R-squared evaluates how much of the variability in the
-#'         actual values is explained by the model.}
-#'         \cite{(\href{http://www.ats.ucla.edu/stat/mult_pkg/faq/general/coefficient_of_variation.htm}{source: UCLA-FAQ})}
 #'
 #' @return Numeric, the coefficient of variation.
 #'
@@ -28,7 +20,6 @@
 #' fit <- lm(barthtot ~ c160age + c12hour, data = efc)
 #' cv(fit)
 #'
-#' @importFrom stats sd
 #' @export
 cv <- function(x, ...) {
   # return value
@@ -45,9 +36,8 @@ cv <- function(x, ...) {
 }
 
 
-#' @importFrom performance rmse
-#' @importFrom insight get_response
 cv_helper <- function(x) {
+  insight::check_if_installed("performance")
   # check if we have a fitted linear model
   if (inherits(x, c("lm", "lmerMod", "lme", "merModLmerTest")) && !inherits(x, "glm")) {
     # get response
