@@ -1,4 +1,4 @@
-#' @rdname xtab_statistics
+#' @rdname crosstable_statistics
 #' @export
 phi <- function(tab, ...) {
   UseMethod("phi")
@@ -19,24 +19,20 @@ phi.ftable <- function(tab, ...) {
 
 #' @export
 phi.formula <- function(formula, data, ci.lvl = NULL, n = 1000, method = c("dist", "quantile"), ...) {
-  terms <- all.vars(formula)
-  tab <- table(data[[terms[1]]], data[[terms[2]]])
+  formula_terms <- all.vars(formula)
+  tab <- table(data[[formula_terms[1]]], data[[formula_terms[2]]])
   method <- match.arg(method)
 
   if (is.null(ci.lvl) || is.na(ci.lvl)) {
-    .cramer(tab)
+    .cramers_v(tab)
   } else {
-    ci <- data[, terms] %>%
-      sjstats::bootstrap(n) %>%
-      dplyr::mutate(
-        tables = lapply(.data$strap, function(x) {
-          dat <- as.data.frame(x)
-          table(dat[[1]], dat[[2]])
-        }),
-        phis = sapply(.data$tables, function(x) .cramer(x))
-      ) %>%
-      dplyr::pull("phis") %>%
-      boot_ci(ci.lvl = ci.lvl, method = method)
+    straps <- sjstats::bootstrap(data[formula_terms], n)
+    tables <- lapply(straps$strap, function(x) {
+      dat <- as.data.frame(x)
+      table(dat[[1]], dat[[2]])
+    })
+    phis <- sapply(tables, .phi)
+    ci <- boot_ci(phis, ci.lvl = ci.lvl, method = method)
 
     data_frame(
       phi = .phi(tab),
@@ -48,6 +44,7 @@ phi.formula <- function(formula, data, ci.lvl = NULL, n = 1000, method = c("dist
 
 
 .phi <- function(tab) {
+  insight::check_if_installed("MASS")
   # convert to flat table
   if (!inherits(tab, "ftable")) tab <- stats::ftable(tab)
 
